@@ -53,8 +53,18 @@ class Permission(object):
                     subsystem3list = subsystem3s
                 else:
                     raise Exception(f'the subsystem{subsystem3s} is not support,example:"vehicle" or "vehicle,car" or ["vehicle","car"]')
-                # 获取到用户下所有的权限
-                permissions = self._get_permission()
+                try:
+                    # 获取到用户下所有的权限
+                    permissions = self._get_permission()
+                except Exception as e:
+                    # 避免第一次訪問時出錯，再次重試訪問權限
+                    logging.error(f'第一次訪問權限服務出錯，錯誤：{str(e)}')
+                    try:
+                        permissions = self._get_permission()
+                    except Exception as e:
+                        # 避免出500錯誤，返回403
+                        logging.error(f'第二次訪問權限服務出錯，錯誤：{str(e)}')
+                        permissions = {}
                 acts_sup = set()
                 for subsysntem3 in subsystem3list:
                     permission = permissions.get(subsysntem3)
